@@ -17,7 +17,7 @@ Latest Google Chrome browser (stable)
 64
 </installable>
 
-<screenshot>https://www.google.com/chrome/assets/common/images/marquee/chrome-new.jpg</screenshot>
+<screenshot>none</screenshot>
 
 <preinstall>
 echo "deb [arch=amd64] http://dl.google.com/linux/chrome/deb/ stable main">/etc/apt/sources.list.d/chrometemp.list
